@@ -168,7 +168,6 @@ namespace zypp
     RepoVariablesReplacedUrlList & gpgKeyUrls()
     { return _gpgKeyUrls; }
 
-
     const std::set<std::string> & contentKeywords() const
     { hasContent()/*init if not yet done*/; return _keywords.second; }
 
@@ -355,6 +354,11 @@ namespace zypp
       return _packagesPath;
     }
 
+    Pathname predownloadPath() const
+    {
+      return packagesPath() / ".preload";
+    }
+
     DefaultIntegral<unsigned,defaultPriority> priority;
     mutable bool emptybaseurls;
 
@@ -578,6 +582,9 @@ namespace zypp
   void RepoInfo::setPackagesPath( const Pathname &path )
   { _pimpl->packagesPath( path ); }
 
+  Pathname RepoInfo::predownloadPath() const
+  { return _pimpl->predownloadPath(); }
+
   void RepoInfo::setKeepPackages( bool keep )
   { _pimpl->keeppackages = keep; }
 
